# Sanic-RESTful

(Testing)
Sanic-RESTful provides the building blocks for creating a great REST API.

## User Guide

You'll find the user guide and all documentation [here](https://flask-restful.readthedocs.io/)

